@@ -1,7 +1,7 @@
 package Getopt::Long::Dump;
 
 our $DATE = '2016-10-27'; # DATE
-our $VERSION = '0.09'; # VERSION
+our $VERSION = '0.10'; # VERSION
 
 use 5.010;
 use strict;
@@ -64,7 +64,7 @@ sub dump_getopt_long_script {
     my $filename = $args{filename} or return [400, "Please specify filename"];
     my $detres;
     if ($args{skip_detect}) {
-        $detres = [200, "OK (skip_detect)", 1];
+        $detres = [200, "OK (skip_detect)", 1, {"func.module"=>"Getopt::Long", "func.reason"=>"skip detect, forced"}];
     } else {
         $detres = Getopt::Long::Util::detect_getopt_long_script(
             filename => $filename);
@@ -125,7 +125,7 @@ Getopt::Long::Dump - Run a Getopt::Long-based script but only to dump the spec
 
 =head1 VERSION
 
-This document describes version 0.09 of Getopt::Long::Dump (from Perl distribution Getopt-Long-Dump), released on 2016-10-27.
+This document describes version 0.10 of Getopt::Long::Dump (from Perl distribution Getopt-Long-Dump), released on 2016-10-27.
 
 =head1 FUNCTIONS
 
